summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2010-04-26 22:43:06 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2010-04-26 22:51:30 -0500
commit510227e39e05881db277bcdffa69bf954f0d7568 (patch)
tree0af94948b0819bfb91beaea649a75e82f21bf2db
parent7a1f21416695f5bc48ac90b677e40d830e58b60a (diff)
downloadlibpng-1.4.2rc04.tar.gz
[master] Imported from libpng-1.4.2rc04.tarv1.4.2rc04
-rw-r--r--ANNOUNCE2
-rw-r--r--CHANGES2
-rw-r--r--CMakeLists.txt2
-rw-r--r--INSTALL4
-rw-r--r--LICENSE4
-rw-r--r--Makefile.am2
-rw-r--r--Makefile.in2
-rw-r--r--README12
-rwxr-xr-xconfigure22
-rw-r--r--configure.ac4
-rw-r--r--example.c5
-rw-r--r--libpng-1.4.2rc04.txt (renamed from libpng-1.4.2rc03.txt)10
-rw-r--r--libpng.320
-rw-r--r--libpngpf.34
-rw-r--r--png.52
-rw-r--r--png.c6
-rw-r--r--png.h18
-rw-r--r--pngconf.h2
-rw-r--r--pngpriv.h2
-rw-r--r--pngread.c2
-rw-r--r--pngrtran.c2
-rw-r--r--pngrutil.c2
-rw-r--r--pngtest.c2
-rw-r--r--projects/visualc6/readme.txt93
-rw-r--r--projects/visualc6/zlib.props43
-rw-r--r--projects/xcode/libpng.xcodeproj/project.pbxproj4
-rw-r--r--scripts/README.txt12
-rwxr-xr-xscripts/libpng-config-head.in2
-rw-r--r--scripts/libpng.pc.in2
-rw-r--r--scripts/makefile.ne12bsd2
-rw-r--r--scripts/makefile.netbsd2
-rw-r--r--scripts/makefile.openbsd2
-rw-r--r--scripts/png32ce.def2
-rw-r--r--scripts/pngos2.def2
-rw-r--r--scripts/pngwin.def2
35 files changed, 220 insertions, 81 deletions
diff --git a/ANNOUNCE b/ANNOUNCE
index 162a6df5b..23a0bfe17 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -48,7 +48,7 @@ version 1.4.2rc04 [April 27, 2010]
Added the "vstudio" project to replace "visualc6" and "visualc71" which
will be removed from libpng-1.5.0.
Demonstrate in example.c that lang_key should be initialized.
- Set PNG_NO_READ_BGR, PNG_NO_IO_STATE, and PNG_NO_TIME_RFC1143 in
+ Set PNG_NO_READ_BGR, PNG_NO_IO_STATE, and PNG_NO_TIME_RFC1123 in
contrib/pngminim/decoder/pngusr.h to make a smaller decoder application.
Send comments/corrections/commendations to png-mng-implement at lists.sf.net
diff --git a/CHANGES b/CHANGES
index cf40a02d6..5af409606 100644
--- a/CHANGES
+++ b/CHANGES
@@ -2559,7 +2559,7 @@ version 1.4.2rc04 [April 27, 2010]
Added the "vstudio" project to replace "visualc6" and "visualc71" which
will be removed from libpng-1.5.0.
Demonstrate in example.c that lang_key should be initialized.
- Set PNG_NO_READ_BGR, PNG_NO_IO_STATE, and PNG_NO_TIME_RFC1143 in
+ Set PNG_NO_READ_BGR, PNG_NO_IO_STATE, and PNG_NO_TIME_RFC1123 in
contrib/pngminim/decoder/pngusr.h to make a smaller decoder application.
Send comments/corrections/commendations to png-mng-implement at lists.sf.net
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 1cef18857..847bbba3e 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -213,7 +213,7 @@ configure_file(${CMAKE_CURRENT_SOURCE_DIR}/libpng-config.in
# SET UP LINKS
if(PNG_SHARED)
set_target_properties(${PNG_LIB_NAME} PROPERTIES
-# VERSION 14.${PNGLIB_RELEASE}.1.4.2rc03
+# VERSION 14.${PNGLIB_RELEASE}.1.4.2rc04
VERSION 14.${PNGLIB_RELEASE}.0
SOVERSION 14
CLEAN_DIRECT_OUTPUT 1)
diff --git a/INSTALL b/INSTALL
index 1abd80610..3ce420a58 100644
--- a/INSTALL
+++ b/INSTALL
@@ -1,5 +1,5 @@
-Installing libpng version 1.4.2rc03 - April 24, 2010
+Installing libpng version 1.4.2rc04 - April 27, 2010
On Unix/Linux and similar systems, you can simply type
@@ -46,7 +46,7 @@ to have access to the zlib.h and zconf.h include files that
correspond to the version of zlib that's installed.
You can rename the directories that you downloaded (they
-might be called "libpng-1.4.2rc03" or "libpng14" and "zlib-1.2.3"
+might be called "libpng-1.4.2rc04" or "libpng14" and "zlib-1.2.3"
or "zlib123") so that you have directories called "zlib" and "libpng".
Your directory structure should look like this:
diff --git a/LICENSE b/LICENSE
index be7f1459f..afc3ecfa5 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.4.2rc03, April 24, 2010, are
+libpng versions 1.2.6, August 15, 2004, through 1.4.2rc04, April 27, 2010, are
Copyright (c) 2004, 2006-2007 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-April 24, 2010
+April 27, 2010
diff --git a/Makefile.am b/Makefile.am
index d2009eb7c..6620e1dd1 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -73,7 +73,7 @@ EXTRA_DIST= \
${srcdir}/contrib/pngsuite/* \
${srcdir}/contrib/visupng/* \
$(TESTS) \
- example.c libpng-1.4.2rc03.txt
+ example.c libpng-1.4.2rc04.txt
CLEANFILES= pngout.png libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@.pc libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@-config libpng.vers \
libpng.sym
diff --git a/Makefile.in b/Makefile.in
index c5a0cdfba..f4151b5f9 100644
--- a/Makefile.in
+++ b/Makefile.in
@@ -333,7 +333,7 @@ EXTRA_DIST = \
${srcdir}/contrib/pngsuite/* \
${srcdir}/contrib/visupng/* \
$(TESTS) \
- example.c libpng-1.4.2rc03.txt
+ example.c libpng-1.4.2rc04.txt
CLEANFILES = pngout.png libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@.pc libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@-config libpng.vers \
libpng.sym
diff --git a/README b/README
index 27ff03119..3f669442f 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.4.2rc03 - April 24, 2010 (shared library 14.0)
+README for libpng version 1.4.2rc04 - April 27, 2010 (shared library 14.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
@@ -185,9 +185,9 @@ Files in this distribution:
makefile.std => Generic UNIX makefile (cc, creates static
libpng.a)
makefile.elf => Linux/ELF makefile symbol versioning,
- gcc, creates libpng14.so.14.1.4.2rc03)
+ gcc, creates libpng14.so.14.1.4.2rc04)
makefile.linux => Linux/ELF makefile
- (gcc, creates libpng14.so.14.1.4.2rc03)
+ (gcc, creates libpng14.so.14.1.4.2rc04)
makefile.gcc => Generic makefile (gcc, creates static libpng.a)
makefile.knr => Archaic UNIX Makefile that converts files with
ansi2knr (Requires ansi2knr.c from
@@ -209,12 +209,12 @@ Files in this distribution:
makefile.openbsd => OpenBSD makefile
makefile.sgi => Silicon Graphics IRIX (cc, creates static lib)
makefile.sggcc => Silicon Graphics
- (gcc, creates libpng14.so.14.1.4.2rc03)
+ (gcc, creates libpng14.so.14.1.4.2rc04)
makefile.sunos => Sun makefile
makefile.solaris => Solaris 2.X makefile
- (gcc, creates libpng14.so.14.1.4.2rc03)
+ (gcc, creates libpng14.so.14.1.4.2rc04)
makefile.so9 => Solaris 9 makefile
- (gcc, creates libpng14.so.14.1.4.2rc03)
+ (gcc, creates libpng14.so.14.1.4.2rc04)
makefile.32sunu => Sun Ultra 32-bit makefile
makefile.64sunu => Sun Ultra 64-bit makefile
makefile.sco => For SCO OSr5 ELF and Unixware 7 with Native cc
diff --git a/configure b/configure
index 2245d4894..7a25325ba 100755
--- a/configure
+++ b/configure
@@ -1,6 +1,6 @@
#! /bin/sh
# Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.65 for libpng 1.4.2rc03.
+# Generated by GNU Autoconf 2.65 for libpng 1.4.2rc04.
#
# Report bugs to <png-mng-implement@lists.sourceforge.net>.
#
@@ -701,8 +701,8 @@ MAKEFLAGS=
# Identity of this package.
PACKAGE_NAME='libpng'
PACKAGE_TARNAME='libpng'
-PACKAGE_VERSION='1.4.2rc03'
-PACKAGE_STRING='libpng 1.4.2rc03'
+PACKAGE_VERSION='1.4.2rc04'
+PACKAGE_STRING='libpng 1.4.2rc04'
PACKAGE_BUGREPORT='png-mng-implement@lists.sourceforge.net'
PACKAGE_URL=''
@@ -1432,7 +1432,7 @@ if test "$ac_init_help" = "long"; then
# Omit some internal or obsolete options to make the list less imposing.
# This message is too long to be a string in the A/UX 3.1 sh.
cat <<_ACEOF
-\`configure' configures libpng 1.4.2rc03 to adapt to many kinds of systems.
+\`configure' configures libpng 1.4.2rc04 to adapt to many kinds of systems.
Usage: $0 [OPTION]... [VAR=VALUE]...
@@ -1502,7 +1502,7 @@ fi
if test -n "$ac_init_help"; then
case $ac_init_help in
- short | recursive ) echo "Configuration of libpng 1.4.2rc03:";;
+ short | recursive ) echo "Configuration of libpng 1.4.2rc04:";;
esac
cat <<\_ACEOF
@@ -1607,7 +1607,7 @@ fi
test -n "$ac_init_help" && exit $ac_status
if $ac_init_version; then
cat <<\_ACEOF
-libpng configure 1.4.2rc03
+libpng configure 1.4.2rc04
generated by GNU Autoconf 2.65
Copyright (C) 2009 Free Software Foundation, Inc.
@@ -2032,7 +2032,7 @@ cat >config.log <<_ACEOF
This file contains any messages produced by compilers while
running configure, to aid debugging if configure makes a mistake.
-It was created by libpng $as_me 1.4.2rc03, which was
+It was created by libpng $as_me 1.4.2rc04, which was
generated by GNU Autoconf 2.65. Invocation command line was
$ $0 $@
@@ -2840,7 +2840,7 @@ fi
# Define the identity of the package.
PACKAGE='libpng'
- VERSION='1.4.2rc03'
+ VERSION='1.4.2rc04'
cat >>confdefs.h <<_ACEOF
@@ -2904,7 +2904,7 @@ fi
-PNGLIB_VERSION=1.4.2rc03
+PNGLIB_VERSION=1.4.2rc04
PNGLIB_MAJOR=1
PNGLIB_MINOR=4
PNGLIB_RELEASE=2
@@ -12032,7 +12032,7 @@ cat >>$CONFIG_STATUS <<\_ACEOF || ac_write_fail=1
# report actual input values of CONFIG_FILES etc. instead of their
# values after options handling.
ac_log="
-This file was extended by libpng $as_me 1.4.2rc03, which was
+This file was extended by libpng $as_me 1.4.2rc04, which was
generated by GNU Autoconf 2.65. Invocation command line was
CONFIG_FILES = $CONFIG_FILES
@@ -12098,7 +12098,7 @@ _ACEOF
cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
ac_cs_version="\\
-libpng config.status 1.4.2rc03
+libpng config.status 1.4.2rc04
configured by $0, generated by GNU Autoconf 2.65,
with options \\"\$ac_cs_config\\"
diff --git a/configure.ac b/configure.ac
index 9b17e80ac..79c21ccf1 100644
--- a/configure.ac
+++ b/configure.ac
@@ -18,12 +18,12 @@ AC_PREREQ(2.59)
dnl Version number stuff here:
-AC_INIT([libpng], [1.4.2rc03], [png-mng-implement@lists.sourceforge.net])
+AC_INIT([libpng], [1.4.2rc04], [png-mng-implement@lists.sourceforge.net])
AM_INIT_AUTOMAKE
dnl stop configure from automagically running automake
AM_MAINTAINER_MODE
-PNGLIB_VERSION=1.4.2rc03
+PNGLIB_VERSION=1.4.2rc04
PNGLIB_MAJOR=1
PNGLIB_MINOR=4
PNGLIB_RELEASE=2
diff --git a/example.c b/example.c
index da67ff684..25069c5db 100644
--- a/example.c
+++ b/example.c
@@ -2,7 +2,7 @@
#if 0 /* in case someone actually tries to compile this */
/* example.c - an example of using libpng
- * Last changed in libpng 1.4.2 [April 24, 2010]
+ * Last changed in libpng 1.4.2 [April 27, 2010]
* This file has been placed in the public domain by the authors.
* Maintained 1998-2010 Glenn Randers-Pehrson
* Maintained 1996, 1997 Andreas Dilger)
@@ -687,8 +687,11 @@ void write_png(char *file_name /* , ... other image information ... */)
text_ptr[2].compression = PNG_TEXT_COMPRESSION_zTXt;
#ifdef PNG_iTXt_SUPPORTED
text_ptr[0].lang = NULL;
+ text_ptr[0].lang_key = NULL;
text_ptr[1].lang = NULL;
+ text_ptr[1].lang_key = NULL;
text_ptr[2].lang = NULL;
+ text_ptr[2].lang_key = NULL;
#endif
png_set_text(png_ptr, info_ptr, text_ptr, 3);
diff --git a/libpng-1.4.2rc03.txt b/libpng-1.4.2rc04.txt
index b9dda0d83..796aa07ad 100644
--- a/libpng-1.4.2rc03.txt
+++ b/libpng-1.4.2rc04.txt
@@ -1,6 +1,6 @@
libpng.txt - A description on how to use and modify libpng
- libpng version 1.4.2rc03 - April 24, 2010
+ libpng version 1.4.2rc04 - April 27, 2010
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2009 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@ libpng.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.4.2rc03 - April 24, 2010
+ libpng versions 0.97, January 1998, through 1.4.2rc04 - April 27, 2010
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2009 Glenn Randers-Pehrson
@@ -903,7 +903,7 @@ things.
As of libpng version 1.2.9, png_set_expand_gray_1_2_4_to_8() was
added. It expands the sample depth without changing tRNS to alpha.
-As of libpng version 1.4.2rc03, not all possible expansions are supported.
+As of libpng version 1.4.2rc04, not all possible expansions are supported.
In the following table, the 01 means grayscale with depth<8, 31 means
indexed with depth<8, other numerals represent the color type, "T" means
@@ -3297,13 +3297,13 @@ Other rules can be inferred by inspecting the libpng source.
XIII. Y2K Compliance in libpng
-April 24, 2010
+April 27, 2010
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.4.2rc03 are Y2K compliant. It is my belief that earlier
+upward through 1.4.2rc04 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has three year fields. One is a 2-byte unsigned integer that
diff --git a/libpng.3 b/libpng.3
index 97911fe38..c946d2ab6 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,6 +1,6 @@
-.TH LIBPNG 3 "April 24, 2010"
+.TH LIBPNG 3 "April 27, 2010"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.4.2rc03
+libpng \- Portable Network Graphics (PNG) Reference Library 1.4.2rc04
.SH SYNOPSIS
\fI\fB
@@ -785,7 +785,7 @@ Following is a copy of the libpng.txt file that accompanies libpng.
.SH LIBPNG.TXT
libpng.txt - A description on how to use and modify libpng
- libpng version 1.4.2rc03 - April 24, 2010
+ libpng version 1.4.2rc04 - April 27, 2010
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2009 Glenn Randers-Pehrson
@@ -796,7 +796,7 @@ libpng.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.4.2rc03 - April 24, 2010
+ libpng versions 0.97, January 1998, through 1.4.2rc04 - April 27, 2010
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2009 Glenn Randers-Pehrson
@@ -1688,7 +1688,7 @@ things.
As of libpng version 1.2.9, png_set_expand_gray_1_2_4_to_8() was
added. It expands the sample depth without changing tRNS to alpha.
-As of libpng version 1.4.2rc03, not all possible expansions are supported.
+As of libpng version 1.4.2rc04, not all possible expansions are supported.
In the following table, the 01 means grayscale with depth<8, 31 means
indexed with depth<8, other numerals represent the color type, "T" means
@@ -4082,13 +4082,13 @@ Other rules can be inferred by inspecting the libpng source.
.SH XIII. Y2K Compliance in libpng
-April 24, 2010
+April 27, 2010
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.4.2rc03 are Y2K compliant. It is my belief that earlier
+upward through 1.4.2rc04 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has three year fields. One is a 2-byte unsigned integer that
@@ -4322,7 +4322,7 @@ possible without all of you.
Thanks to Frank J. T. Wojcik for helping with the documentation.
-Libpng version 1.4.2rc03 - April 24, 2010:
+Libpng version 1.4.2rc04 - April 27, 2010:
Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
@@ -4345,7 +4345,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.4.2rc03, April 24, 2010, are
+libpng versions 1.2.6, August 15, 2004, through 1.4.2rc04, April 27, 2010, are
Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -4444,7 +4444,7 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-April 24, 2010
+April 27, 2010
.\" end of man page
diff --git a/libpngpf.3 b/libpngpf.3
index 4a129147d..f250765d9 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
-.TH LIBPNGPF 3 "April 24, 2010"
+.TH LIBPNGPF 3 "April 27, 2010"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.4.2rc03
+libpng \- Portable Network Graphics (PNG) Reference Library 1.4.2rc04
(private functions)
.SH SYNOPSIS
\fB#include <png.h>\fP
diff --git a/png.5 b/png.5
index 3d732fb5a..b6e09ea41 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "April 24, 2010"
+.TH PNG 5 "April 27, 2010"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/png.c b/png.c
index d89d5e021..d868a1cf0 100644
--- a/png.c
+++ b/png.c
@@ -17,7 +17,7 @@
#include "pngpriv.h"
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_4_2rc03 Your_png_h_is_not_version_1_4_2rc03;
+typedef version_1_4_2rc04 Your_png_h_is_not_version_1_4_2rc04;
/* Version information for C files. This had better match the version
* string defined in png.h.
@@ -551,13 +551,13 @@ png_get_copyright(png_structp png_ptr)
#else
#ifdef __STDC__
return ((png_charp) PNG_STRING_NEWLINE \
- "libpng version 1.4.2rc03 - April 24, 2010" PNG_STRING_NEWLINE \
+ "libpng version 1.4.2rc04 - April 27, 2010" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2010 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE);
#else
- return ((png_charp) "libpng version 1.4.2rc03 - April 24, 2010\
+ return ((png_charp) "libpng version 1.4.2rc04 - April 27, 2010\
Copyright (c) 1998-2010 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.");
diff --git a/pngconf.h b/pngconf.h
index 740b768a0..c56b4a4a0 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.4.2rc03 - April 24, 2010
+ * libpng version 1.4.2rc04 - April 27, 2010
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngpriv.h b/pngpriv.h
index ed3af7784..a8a52aebb 100644
--- a/pngpriv.h
+++ b/pngpriv.h
@@ -1,7 +1,7 @@
/* pngpriv.h - private declarations for use inside libpng
*
- * libpng version 1.4.2rc03 - April 24, 2010
+ * libpng version 1.4.2rc04 - April 27, 2010
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngread.c b/pngread.c
index 5473b2eea..42974c897 100644
--- a/pngread.c
+++ b/pngread.c
@@ -1,7 +1,7 @@
/* pngread.c - read a PNG file
*
- * Last changed in libpng 1.4.2 [April 24, 2010]
+ * Last changed in libpng 1.4.2 [April 27, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngrtran.c b/pngrtran.c
index 1538a81ab..48e1664e0 100644
--- a/pngrtran.c
+++ b/pngrtran.c
@@ -1,7 +1,7 @@
/* pngrtran.c - transforms the data in a row for PNG readers
*
- * Last changed in libpng 1.4.2 [April 24, 2010]
+ * Last changed in libpng 1.4.2 [April 27, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngrutil.c b/pngrutil.c
index 26b834e95..2fc0dd285 100644
--- a/pngrutil.c
+++ b/pngrutil.c
@@ -1,7 +1,7 @@
/* pngrutil.c - utilities to read a PNG file
*
- * Last changed in libpng 1.4.2 [April 24, 2010]
+ * Last changed in libpng 1.4.2 [April 27, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngtest.c b/pngtest.c
index 03817c301..17afb15ae 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -1627,4 +1627,4 @@ main(int argc, char *argv[])
}
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_4_2rc03 your_png_h_is_not_version_1_4_2rc03;
+typedef version_1_4_2rc04 your_png_h_is_not_version_1_4_2rc04;
diff --git a/projects/visualc6/readme.txt b/projects/visualc6/readme.txt
new file mode 100644
index 000000000..4187b70b5
--- /dev/null
+++ b/projects/visualc6/readme.txt
@@ -0,0 +1,93 @@
+
+VisualStudio instructions
+
+libpng version 1.4.2rc04 - April 27, 2010
+
+Copyright (c) 1998-2010 Glenn Randers-Pehrson
+
+This code is released under the libpng license.
+For conditions of distribution and use, see the disclaimer
+and license in png.h
+
+This directory contains support for building libpng under MicroSoft
+VisualStudio 2010. It may also work under later versions of VisualStudio.
+You should be familiar with VisualStudio before using this directory.
+
+This is a slightly modified copy of the 'vstudio' solution from libpng
+1.5; it is intended to provide compatibility for libpng 1.4 with later
+releases of zlib (from 1.2.4) and to provide a migration aid for 1.5.
+
+A 'VB' DLL is no longer produced - use the standard 'Release' DLL.
+
+Initial preparations
+====================
+You should install the 'official' build of zlib on your system - follow the
+instructions provided on http://www.zlib.net. When a new release is being
+made of zlib the instructions disappear for a while until the new official
+build is available. You will have to wait.
+
+You must enter some information in zlib.props before attempting to build
+with this 'solution'. Please read and edit zlib.props first. You will
+probably not be familiar with the contents of zlib.props - do not worry,
+it is mostly harmless.
+
+Make sure that your official build layout matches the requirements listed
+in zlib.props. Prior to zlib-1.2.4 the official build (1.2.3) placed
+include and library files in different directories - if you find this
+has happened just put them all in the same directory.
+
+This is all you need to do to build the 'release' and 'release library'
+configurations.
+
+Debugging
+=========
+The release configurations default to /Ox optimization. Full debugging
+information is produced (in the .pdb), but if you encounter a problem the
+optimization may make it difficult to debug. Simply rebuild with a lower
+optimization level (e.g. /Od.)
+
+Stop reading here
+=================
+You have enough information to build a working application.
+
+Debug versions have limited support
+===================================
+This solution includes limited support for debug versions of libpng. You
+do not need these unless your own solution itself uses debug builds (it is
+far more effective to debug on the release builds, there is no point building
+a special debug build.)
+
+If, despite the previous paragraph, you still feel you need a debug build you
+will have to download the zlib source as well (http://www.zlib.net) and include
+the directory where you unpack it in zlib.props. This solution will then be
+able to build a minimal zlib sufficient for libpng. This build is only
+suitable for making a debug libpng.
+
+The debug build of libpng is minimally supported. Support for debug builds of
+zlib is also minimal. You really don't want to do this.
+
+This solution only supports the Multi-Threaded DLL C Runtime
+============================================================
+If you examine the solution you will find that it very deliberately lists
+exactly which MicroSoft DLLs it is linking against. It explicitly links
+against msvcrt.lib. The debug version links against msvcrtd.lib (this is
+why it is a debug version - it's nothing to do with having any special
+debug support, it doesn't).
+
+These versions of the MicroSoft C runtime correspond to the compiler flags
+/MD (release) and /MDd (debug) - the "Multi-Threaded DLL" implementation of the
+C runtime library.
+
+If you need to change this then you will have to make sure that both the
+compiler flags and the ".lib" in the linker dependences match up. Fortunately
+neither zlib nor libpng require libraries other than a C runtime and
+kernel32.
+
+You cannot pass (FILE*) objects from a different runtime (including msvcrtd
+to msvcrt) to libpng. If you do then your program will crash within libpng
+when it first makes a file read or write call.
+
+It is likely if you have read this far that you have found you can't avoid
+having multiple C runtimes in your program. This is OK, it does work, but
+you will have to implement the libpng file read/write callbacks rather than
+using the internal libpng default. This is easy.
diff --git a/projects/visualc6/zlib.props b/projects/visualc6/zlib.props
new file mode 100644
index 000000000..b29df0ca4
--- /dev/null
+++ b/projects/visualc6/zlib.props
@@ -0,0 +1,43 @@
+<?xml version="1.0" encoding="utf-8"?>
+<!--
+ * zlib.props - location of zlib source and build
+ *
+ * libpng version 1.4.2rc04 - April 27, 2010
+ *
+ * Copyright (c) 1998-2010 Glenn Randers-Pehrson
+ *
+ * This code is released under the libpng license.
+ * For conditions of distribution and use, see the disclaimer
+ * and license in png.h
+
+ * You must edit this file to record the location of the zlib
+ * official and debug builds unless they are in the default
+ * directories:
+
+ * official: zlib1
+ * debug: zlib debug
+ -->
+
+<Project ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
+ <PropertyGroup Label="Globals">
+ <!-- Place the name of the directory containing the official
+ build of zlib and the corresponding header files in this
+ property. The directory is expected to contain at least:
+
+ zdll.lib # The DLL import library
+ zlib.lib # The static library
+ zlib.h # The header file
+ zconf.h # Another header file included by zlib.h
+ -->
+ <ZLib1Dir>..\..\..\..\zlib124-dll\zlib-1.2.4</ZLib1Dir>
+
+ <!-- Place the name of the directory containing the source of
+ zlib used for debugging in this property.
+ The directory need only contain the '.c' and '.h' files
+ from the source. For your own sanity make sure that the
+ '.h' files in the source match those from the 'official'
+ build above.
+ -->
+ <ZLibSrcDir>..\..\..\..\zlib-1.2.4</ZLibSrcDir>
+ </PropertyGroup>
+</Project>
diff --git a/projects/xcode/libpng.xcodeproj/project.pbxproj b/projects/xcode/libpng.xcodeproj/project.pbxproj
index 1de8f821e..018383544 100644
--- a/projects/xcode/libpng.xcodeproj/project.pbxproj
+++ b/projects/xcode/libpng.xcodeproj/project.pbxproj
@@ -226,7 +226,7 @@
COPY_PHASE_STRIP = NO;
DYLIB_COMPATIBILITY_VERSION = 14;
DYLIB_CURRENT_VERSION = 14;
- FRAMEWORK_VERSION = 1.4.2rc03;
+ FRAMEWORK_VERSION = 1.4.2rc04;
GCC_PRECOMPILE_PREFIX_HEADER = NO;
GCC_PREFIX_HEADER = "";
INFOPLIST_FILE = Info.plist;
@@ -244,7 +244,7 @@
buildSettings = {
DYLIB_COMPATIBILITY_VERSION = 14;
DYLIB_CURRENT_VERSION = 14;
- FRAMEWORK_VERSION = 1.4.2rc03;
+ FRAMEWORK_VERSION = 1.4.2rc04;
GCC_PRECOMPILE_PREFIX_HEADER = NO;
GCC_PREFIX_HEADER = "";
INFOPLIST_FILE = Info.plist;
diff --git a/scripts/README.txt b/scripts/README.txt
index e48210a51..9a5ff1d78 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,8 +1,8 @@
-Makefiles for libpng version 1.4.2rc03 - April 24, 2010
+Makefiles for libpng version 1.4.2rc04 - April 27, 2010
makefile.linux => Linux/ELF makefile
- (gcc, creates libpng14.so.14.1.4.2rc03)
+ (gcc, creates libpng14.so.14.1.4.2rc04)
makefile.gcc => Generic makefile (gcc, creates static libpng.a)
makefile.knr => Archaic UNIX Makefile that converts files with
ansi2knr (Requires ansi2knr.c from
@@ -20,7 +20,7 @@ Makefiles for libpng version 1.4.2rc03 - April 24, 2010
makefile.dec => DEC Alpha UNIX makefile
makefile.dj2 => DJGPP 2 makefile
makefile.elf => Linux/ELF makefile symbol versioning,
- gcc, creates libpng14.so.14.1.4.2rc03)
+ gcc, creates libpng14.so.14.1.4.2rc04)
makefile.freebsd => FreeBSD makefile
makefile.gcc => Generic gcc makefile
makefile.hpgcc => HPUX makefile using gcc
@@ -36,12 +36,12 @@ Makefiles for libpng version 1.4.2rc03 - April 24, 2010
makefile.os2 => OS/2 Makefile (gcc and emx, requires pngos2.def)
makefile.sco => For SCO OSr5 ELF and Unixware 7 with Native cc
makefile.sggcc => Silicon Graphics (gcc,
- creates libpng14.so.14.1.4.2rc03)
+ creates libpng14.so.14.1.4.2rc04)
makefile.sgi => Silicon Graphics IRIX makefile (cc, creates static lib)
makefile.solaris => Solaris 2.X makefile (gcc,
- creates libpng14.so.14.1.4.2rc03)
+ creates libpng14.so.14.1.4.2rc04)
makefile.so9 => Solaris 9 makefile (gcc,
- creates libpng14.so.14.1.4.2rc03)
+ creates libpng14.so.14.1.4.2rc04)
makefile.std => Generic UNIX makefile (cc, creates static libpng.a)
makefile.sunos => Sun makefile
makefile.32sunu => Sun Ultra 32-bit makefile
diff --git a/scripts/libpng-config-head.in b/scripts/libpng-config-head.in
index 6c6ddc6a9..c95c4e612 100755
--- a/scripts/libpng-config-head.in
+++ b/scripts/libpng-config-head.in
@@ -11,7 +11,7 @@
# Modeled after libxml-config.
-version=1.4.2rc03
+version=1.4.2rc04
prefix=""
libdir=""
libs=""
diff --git a/scripts/libpng.pc.in b/scripts/libpng.pc.in
index 2cb5756bb..88026c22c 100644
--- a/scripts/libpng.pc.in
+++ b/scripts/libpng.pc.in
@@ -5,6 +5,6 @@ includedir=@includedir@/libpng14
Name: libpng
Description: Loads and saves PNG files
-Version: 1.4.2rc03
+Version: 1.4.2rc04
Libs: -L${libdir} -lpng14
Cflags: -I${includedir}
diff --git a/scripts/makefile.ne12bsd b/scripts/makefile.ne12bsd
index 7d8cbe433..c73e94e82 100644
--- a/scripts/makefile.ne12bsd
+++ b/scripts/makefile.ne12bsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include/libpng14
LIB= png14
SHLIB_MAJOR= 0
-SHLIB_MINOR= 1.4.2rc03
+SHLIB_MINOR= 1.4.2rc04
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.netbsd b/scripts/makefile.netbsd
index b2e9b5fcb..d2f1a5486 100644
--- a/scripts/makefile.netbsd
+++ b/scripts/makefile.netbsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include
LIB= png
SHLIB_MAJOR= 3
-SHLIB_MINOR= 1.4.2rc03
+SHLIB_MINOR= 1.4.2rc04
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.openbsd b/scripts/makefile.openbsd
index 00ddd9455..0594ac308 100644
--- a/scripts/makefile.openbsd
+++ b/scripts/makefile.openbsd
@@ -11,7 +11,7 @@ LIBDIR= ${PREFIX}/lib
MANDIR= ${PREFIX}/man/cat
SHLIB_MAJOR= 0
-SHLIB_MINOR= 1.4.2rc03
+SHLIB_MINOR= 1.4.2rc04
LIB= png
SRCS= png.c pngerror.c pngget.c pngmem.c pngpread.c \
diff --git a/scripts/png32ce.def b/scripts/png32ce.def
index f1d170c2d..19b1ef190 100644
--- a/scripts/png32ce.def
+++ b/scripts/png32ce.def
@@ -15,7 +15,7 @@ LIBRARY lpngce
png_get_int_32
EXPORTS
-;Version 1.4.2rc03
+;Version 1.4.2rc04
png_build_grayscale_palette @1
; png_check_sig @2
png_chunk_error @3
diff --git a/scripts/pngos2.def b/scripts/pngos2.def
index 990e32141..03a0585a9 100644
--- a/scripts/pngos2.def
+++ b/scripts/pngos2.def
@@ -2,7 +2,7 @@
; PNG.LIB module definition file for OS/2
;----------------------------------------
-; Version 1.4.2rc03
+; Version 1.4.2rc04
LIBRARY PNG
DESCRIPTION "PNG image compression library for OS/2"
diff --git a/scripts/pngwin.def b/scripts/pngwin.def
index c93025dc2..c722a2c1d 100644
--- a/scripts/pngwin.def
+++ b/scripts/pngwin.def
@@ -5,7 +5,7 @@
LIBRARY
EXPORTS
-;Version 1.4.2rc03
+;Version 1.4.2rc04
png_build_grayscale_palette
png_chunk_error
png_chunk_warning
diff --git a/png.h b/png.h
index e5f1a7268..54f1c475f 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.4.2rc03 - April 24, 2010
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.4.2rc03 - April 24, 2010: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -171,7 +171,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.4.2rc03, April 24, 2010, are
* Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -283,13 +283,13 @@
* Y2K compliance in libpng:
* =========================
*
- * April 24, 2010
+ * April 27, 2010
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.4.2rc03 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -345,9 +345,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.4.2rc03"
+#define PNG_LIBPNG_VER_STRING "1.4.2rc04"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.4.2rc03 - April 24, 2010\n"
+ " libpng version 1.4.2rc04 - April 27, 2010\n"
#define PNG_LIBPNG_VER_SONUM 14
#define PNG_LIBPNG_VER_DLLNUM 14
@@ -360,7 +360,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 03
+#define PNG_LIBPNG_VER_BUILD 04
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -1469,7 +1469,7 @@ struct png_struct_def
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_4_2rc03;
+typedef png_structp version_1_4_2rc04;
typedef png_struct FAR * FAR * png_structpp;
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.4.2rc03 - April 24, 2010
+ * libpng version 1.4.2rc04 - April 27, 2010
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.4.2rc03 - April 24, 2010: Glenn
+ * libpng versions 0.97, January 1998, through 1.4.2rc04 - April 27, 2010: Glenn
* See also "Contributing Authors", below.
*
@@ -171,7 +171,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.4.2rc03, April 24, 2010, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.4.2rc04, April 27, 2010, are
* Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -283,13 +283,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.4.2rc03 are Y2K compliant. It is my belief that earlier
+ * upward through 1.4.2rc04 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*